@@ -98,7 +98,8 @@ DOCUMENTATION__oauth_cookie = SwaggerDocumentation(
                 arg_type=bool,
                 description="Whether or not the returned cookie will act as a remember me cookie"
             )
-        ]
+        ],
+        response=SwaggerFlatResponse()
     )
 )
 
@@ -126,6 +127,17 @@ DOCUMENTATION__oauth_refresh = SwaggerDocumentation(
     )
 )
 
+DOCUMENTATION__oauth_refresh_cookie = SwaggerDocumentation(
+    tags="OAuth",
+    security=False,
+    methods=SwaggerMethod(
+        name="OAuth Refresh Cookie",
+        description="Refresh your Cookie",
+        method=REST__POST,
+        response=SwaggerFlatResponse()
+    )
+)
+
 DOCUMENTATION__submit = SwaggerDocumentation(
     tags="Queries",
     methods=SwaggerMethod(
